@@ -1,16 +1,17 @@
 // Copyright 2021 The Gitea Authors. All rights reserved.
-// Use of this source code is governed by a MIT-style
-// license that can be found in the LICENSE file.
+// SPDX-License-Identifier: MIT
 
 package users
 
 import (
+	stdctx "context"
+
 	"code.gitea.io/tea/cmd/flags"
 	"code.gitea.io/tea/modules/context"
 	"code.gitea.io/tea/modules/print"
 
 	"code.gitea.io/sdk/gitea"
-	"github.com/urfave/cli/v2"
+	"github.com/urfave/cli/v3"
 )
 
 var userFieldsFlag = flags.FieldsFlag(print.UserFields, []string{
@@ -32,7 +33,7 @@ var CmdUserList = cli.Command{
 }
 
 // RunUserList list users
-func RunUserList(cmd *cli.Context) error {
+func RunUserList(_ stdctx.Context, cmd *cli.Command) error {
 	ctx := context.InitCommand(cmd)
 
 	fields, err := userFieldsFlag.GetValues(cmd)
@@ -42,7 +43,7 @@ func RunUserList(cmd *cli.Context) error {
 
 	client := ctx.Login.Client()
 	users, _, err := client.AdminListUsers(gitea.AdminListUsersOptions{
-		ListOptions: ctx.GetListOptions(),
+		ListOptions: flags.GetListOptions(),
 	})
 	if err != nil {
 		return err
