@@ -1,15 +1,19 @@
 // Copyright 2020 The Gitea Authors. All rights reserved.
-// Use of this source code is governed by a MIT-style
-// license that can be found in the LICENSE file.
+// SPDX-License-Identifier: MIT
 
 package login
 
 import (
+	"context"
+	"log"
+	"os"
+	"os/exec"
+
 	"code.gitea.io/tea/cmd/flags"
 	"code.gitea.io/tea/modules/config"
 
 	"github.com/skratchdot/open-golang/open"
-	"github.com/urfave/cli/v2"
+	"github.com/urfave/cli/v3"
 )
 
 // CmdLoginEdit represents to login a gitea server.
@@ -23,6 +27,15 @@ var CmdLoginEdit = cli.Command{
 	Flags:       []cli.Flag{&flags.OutputFlag},
 }
 
-func runLoginEdit(_ *cli.Context) error {
+func runLoginEdit(_ context.Context, _ *cli.Command) error {
+	if e, ok := os.LookupEnv("EDITOR"); ok && e != "" {
+		cmd := exec.Command(e, config.GetConfigPath())
+		cmd.Stdin = os.Stdin
+		cmd.Stdout = os.Stdout
+		cmd.Stderr = os.Stderr
+		if err := cmd.Run(); err != nil {
+			log.Fatal(err.Error())
+		}
+	}
 	return open.Start(config.GetConfigPath())
 }
