@@ -1,15 +1,16 @@
 // Copyright 2019 The Gitea Authors. All rights reserved.
-// Use of this source code is governed by a MIT-style
-// license that can be found in the LICENSE file.
+// SPDX-License-Identifier: MIT
 
 package cmd
 
 import (
+	stdctx "context"
+
 	"code.gitea.io/tea/cmd/organizations"
 	"code.gitea.io/tea/modules/context"
 	"code.gitea.io/tea/modules/print"
 
-	"github.com/urfave/cli/v2"
+	"github.com/urfave/cli/v3"
 )
 
 // CmdOrgs represents handle organization
@@ -21,7 +22,7 @@ var CmdOrgs = cli.Command{
 	Description: "Show organization details",
 	ArgsUsage:   "[<organization>]",
 	Action:      runOrganizations,
-	Subcommands: []*cli.Command{
+	Commands: []*cli.Command{
 		&organizations.CmdOrganizationList,
 		&organizations.CmdOrganizationCreate,
 		&organizations.CmdOrganizationDelete,
@@ -29,12 +30,12 @@ var CmdOrgs = cli.Command{
 	Flags: organizations.CmdOrganizationList.Flags,
 }
 
-func runOrganizations(cmd *cli.Context) error {
-	ctx := context.InitCommand(cmd)
-	if ctx.Args().Len() == 1 {
-		return runOrganizationDetail(ctx)
+func runOrganizations(ctx stdctx.Context, cmd *cli.Command) error {
+	teaCtx := context.InitCommand(cmd)
+	if teaCtx.Args().Len() == 1 {
+		return runOrganizationDetail(teaCtx)
 	}
-	return organizations.RunOrganizationList(cmd)
+	return organizations.RunOrganizationList(ctx, cmd)
 }
 
 func runOrganizationDetail(ctx *context.TeaContext) error {
