@@ -1,6 +1,5 @@
 // Copyright 2020 The Gitea Authors. All rights reserved.
-// Use of this source code is governed by a MIT-style
-// license that can be found in the LICENSE file.
+// SPDX-License-Identifier: MIT
 
 package task
 
@@ -11,7 +10,7 @@ import (
 
 // ResolveLabelNames returns a list of label IDs for a given list of label names
 func ResolveLabelNames(client *gitea.Client, owner, repo string, labelNames []string) ([]int64, error) {
-	labelIDs := make([]int64, len(labelNames))
+	labelIDs := make([]int64, 0, len(labelNames))
 	labels, _, err := client.ListRepoLabels(owner, repo, gitea.ListLabelsOptions{
 		ListOptions: gitea.ListOptions{Page: -1},
 	})
